@@ -174,6 +174,13 @@ class LibMarkdown(object):
         data = data + "\n"
         return data
 
+    def md_create_body_line2(self, argv):
+        data = '|'
+        for i in argv:
+            data += str(i) + "|"
+        data = data + "\n"
+        return data
+
     def tex_create_body_line(self, argv, path):
         link = os.path.join(path, argv[0].split("||")[0] + '.md')
         data = "|[" + argv[0].replace("||","_") + "](" + link + ")|"
