@@ -90,7 +90,8 @@ class TranslateJson(object):
             if i not in self.history_group:
                 if 'Offset' in self.get_delem(self.js_dict, i):
                     group_step = int(self.get_delem(self.js_dict, i, key='Offset'), 16)
-                    self.history_addrr += group_step
+                    #self.history_addrr += group_step
+                    self.history_addrr = self.history_offset + group_step
                     if leval >= 2:
                         self.history_offset = self.history_addrr
                     else:
@@ -332,6 +333,24 @@ class TranslateJson(object):
     def zero_fill(self, in_hex):
         new_hex = "0x" + in_hex[2:].zfill(self.max_len)
         return new_hex
+
+    def relist_fields(self, fields):
+        fields_len = len(fields)
+        for i in range(fields_len):
+            for j in range(i+1, fields_len):
+                i_f = fields[i]
+                i_index_range = i_f['range']
+                i_scope = i_index_range.strip("[]").split(":")
+                i_end = int(i_scope[0])
+                i_start = int(i_scope[-1])
+                j_f = fields[j]
+                j_index_range = j_f['range']
+                j_scope = j_index_range.strip("[]").split(":")
+                j_end = int(j_scope[0])
+                j_start = int(j_scope[-1])
+                if i_end <= j_end:
+                    fields[i], fields[j] = fields[j], fields[i]
+
     
     def create_md3(self, dpath, lm):
         ls = libsvg.LibSVG()
@@ -359,6 +378,8 @@ class TranslateJson(object):
         fields = self.get_delem(self.js_dict, dpath, key = 'Fields')
         reserve_fields = self.get_reserve_fields(fields)
         fields.extend(reserve_fields)
+        self.relist_fields(fields)
+
         table = ls.create_blank_form()
         for f in fields:
             ls.add_line(table, f['range'])
@@ -387,16 +408,24 @@ class TranslateJson(object):
             fd.write(svg_data)
         register_data = "![](" + svg_name + ")\n<br>"
 
+        line = lm.md_create_title_line(['位域','变量名', '属性', '默认值', '描述'])
+        register_data += "\n\n" + line
         fields_len = len(fields)
         for i in range(fields_len):
-            f = fields[fields_len - i -1]
+            #f = fields[fields_len - i -1]
+            f = fields[i]
             if f['name'] != 'reserved':
-                line = self.add_description(f['name'],f['description'], f['access'])
-                register_data += line + "\n<br>"
+                line = self.add_description_table(lm, [f['range'], f['name'], \
+                        f['access'], f['reset_value'], f['description']])
+                register_data += line
+            else:
+                line = self.add_description_table(lm, [f['range'], f['name'], \
+                        ' ',' ',' '])
+                register_data += line
     
         #table_title = 'Register:' + name + ' ('  + addr + ')'
-        reg_addr_msg = 'address : '  + addr
-        reg_hex_reset = 'reset_value : ' + hex_reset
+        reg_addr_msg = '地址偏移 : '  + addr
+        reg_hex_reset = '默认值 : ' + hex_reset
         register_data = "# " + name + "\n\n" + reg_addr_msg + '<br>' + \
                 reg_hex_reset + '\n' + register_data
         if self.output_md:
@@ -423,6 +452,10 @@ class TranslateJson(object):
             line = "**" + name.upper() + "** **[" + access + "]** :" + msg
         return line
 
+    def add_description_table(self, lm, argv):
+        line = lm.md_create_body_line2(argv)
+        return line
+
     def check_file(self, file_name):
         if self.dir_type != "link":
             return
@@ -502,7 +535,10 @@ class TranslateJson(object):
                     fd.write('* [寄存器列表](' + reg_list_path + ')\n')
                     fd.write('* [寄存器](' + reg_detail_path + ')\n')
                     for i in self.js_dpath:
-                        self.path_addr_dict[i] = self.get_addr(i)
+                        addr = self.get_addr(i)
+                        self.path_addr_dict[i] = addr
+                        name = self.get_delem(self.js_dict, i, key = 'RegName' )
+                        #print(name, "(" + addr + ")")
                     self.max_len = len(self.path_addr_dict[self.js_dpath[-1]][2:])
                     for i in range(int(len(self.js_dpath))):
                         name = self.get_delem(self.js_dict, self.js_dpath[i], key = 'RegName' )
